@@ -1,4 +1,5 @@
-/* $Id: errutils.c,v 1.2 1999/05/31 13:52:05 ian Exp $ */
+/* $Id: errutils.c,v 1.3 2002/03/06 00:37:52 ian Exp $ */
+
 #include <stdio.h>
 #include <errno.h>
 #include "zap.h"
@@ -20,6 +21,7 @@ FILE *efopen(char *file, char *mode)	/* fopen file, die if can't */
 /*
  * warn - print best error message possible and clear errno
  */
+void
 warn(char *fmt, void *arg)
 {
 	char *cmdname;
@@ -34,11 +36,13 @@ warn(char *fmt, void *arg)
 	if (progname != NULL)
 		(void) fprintf(stderr, "%s: ", progname);
 	(void) fprintf(stderr, fmt, arg);
-	if (errno > 0)
-		if (errno < sys_nerr)
+	if (errno > 0) {
+		if (errno < sys_nerr) {
 			(void) fprintf(stderr, " (%s)", sys_errlist[errno]);
-		else
+		} else {
 			(void) fprintf(stderr, " (errno=%d)", errno);
+		}
+	}
 	(void) fputc('\n', stderr);
 	errno = 0;
 }
