@@ -1,13 +1,19 @@
 /*
  * Safer version of system for interactive programs
- * $Id: system.c,v 1.4 1999/05/31 14:19:54 ian Exp $ 
+ * $Id: system.c,v 1.5 2002/03/06 00:37:52 ian Exp $ 
  */
 
-#include <signal.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <fcntl.h>
+#include <signal.h>
+#include <sys/wait.h>
+
 #include "zap.h"
 
-system(char *s)	/* run command line s */
+int
+system(const char *s)	/* run command line s */
 {
 	int status, pid, w, tty;
 	void (*istat)(int), (*qstat)(int);
