@@ -1,8 +1,13 @@
-#include <stdio.h>
-#include "zap.h"
-/* $Id: ttyin2.c,v 1.2 1999/05/31 13:52:06 ian Exp $ */
+/* process response from /dev/tty (K+P version 2).
+ * $Id: ttyin2.c,v 1.3 2002/03/06 00:37:53 ian Exp $
+ */
 
-ttyin()	/* process response from /dev/tty (version 2) */
+#include <stdio.h>
+#include <stdlib.h>
+#include "zap.h"
+
+int
+ttyin()	
 {
 	char buf[BUFSIZ];
 	FILE *efopen();
