@@ -1,13 +1,17 @@
 /*
  * zap.h -- externs for zap program.
- * $Id: zap.h,v 1.2 1999/05/31 14:15:53 ian Exp $
+ * $Id: zap.h,v 1.4 2002/03/06 00:37:53 ian Exp $
  */
 
+#if	1
 #define	PS_ALL	"ps -ax"	/* UNIX, BSD */
-/* #define	PS_ALL	"ps ae" /* System V */
+#else
+#define	PS_ALL	"ps ae" /* System V */
+#endif
 
 void die(char *fmt, void *arg);		/* print error (& errno str), then exit */
 FILE *efopen(char *file, char *mode);	/* fopen file, die if can't */
 void error(char *fmt, void *arg);		/* print warning (& errno str) */
-extern int system(char *s);	/* run command line s */
 extern int ttyin();	/* process response from /dev/tty (version 2) */
+extern int signame(char *name);	/* name to number */
+void warn(char *fmt, void *arg);	/* warning but not exit */
